==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/General/trackchange/translations/trackchange_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Track Change Plugin Settings</source>
        <translation>הגדרות תוסף שינוי רצועה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <location filename="../settingsdialog.ui" line="42"/>
        <location filename="../settingsdialog.ui" line="52"/>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Command to run when Qmmp starts new track</source>
        <translation>פקודה להרצה כאשר Qmmp מתחיל רצועה חדשה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="83"/>
        <source>Command to run toward to end of a track</source>
        <translation>פקודה להרצה לקראת סוף של רצועה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Command to run when Qmmp reaches the end of the playlist</source>
        <translation>פקודה להרצה כאשר Qmmp מגיע אל סוף רשימת הנגינה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>Command to run when title changes (i.e. network streams title)</source>
        <translation>פקודה להרצה כאשר כותרת משתנה (למשל כותרת של זרמי רשת עבודה)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="57"/>
        <source>Artist</source>
        <translation>אמן</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="58"/>
        <source>Album</source>
        <translation>אלבום</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="60"/>
        <source>Title</source>
        <translation>כותרת</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="61"/>
        <source>Track Number</source>
        <translation>מספר רצועה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="62"/>
        <source>Two-digit Track Number</source>
        <translation>מספר רצועה דו ספרתי</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="67"/>
        <source>Disc Number</source>
        <translation>מספר תקליטור</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="68"/>
        <source>File Name</source>
        <translation>שם קובץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="69"/>
        <source>File Path</source>
        <translation>נתיב קובץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="63"/>
        <source>Genre</source>
        <translation>ז׳אנר</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="59"/>
        <source>Album Artist</source>
        <translation>אמן אלבום</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="64"/>
        <source>Comment</source>
        <translation>הערה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="65"/>
        <source>Composer</source>
        <translation>מלחין</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="66"/>
        <source>Duration</source>
        <translation>משך</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="70"/>
        <source>Year</source>
        <translation>שנה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Condition</source>
        <translation>תנאי</translation>
    </message>
</context>
<context>
    <name>TrackChangeFactory</name>
    <message>
        <location filename="../trackchangefactory.cpp" line="30"/>
        <source>Track Change Plugin</source>
        <translation>תוסף שינוי רצועה</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="50"/>
        <source>About Track Change Plugin</source>
        <translation>אודות תוסף שינוי רצועה</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="51"/>
        <source>Qmmp Track Change Plugin</source>
        <translation>תוסף שינוי רצועה של Qmmp</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="52"/>
        <source>This plugin executes external command when current track is changed</source>
        <translation>תוסף זה מבצע פקודה חיצונית כאשר רצועה נוכחית משתנה</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חובר על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/General/trackchange/translations/trackchange_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Track Change Plugin Settings</source>
        <translation>הגדרות תוסף שינוי רצועה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <location filename="../settingsdialog.ui" line="42"/>
        <location filename="../settingsdialog.ui" line="52"/>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Command to run when Qmmp starts new track</source>
        <translation>פקודה להרצה כאשר Qmmp מתחיל רצועה חדשה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="83"/>
        <source>Command to run toward to end of a track</source>
        <translation>פקודה להרצה לקראת סוף של רצועה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Command to run when Qmmp reaches the end of the playlist</source>
        <translation>פקודה להרצה כאשר Qmmp מגיע אל סוף רשימת הנגינה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>Command to run when title changes (i.e. network streams title)</source>
        <translation>פקודה להרצה כאשר כותרת משתנה (למשל כותרת של זרמי רשת עבודה)</translation>
    </message>
</context>
<context>
    <name>TrackChangeFactory</name>
    <message>
        <location filename="../trackchangefactory.cpp" line="30"/>
        <source>Track Change Plugin</source>
        <translation>תוסף שינוי רצועה</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="50"/>
        <source>About Track Change Plugin</source>
        <translation>אודות תוסף שינוי רצועה</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="51"/>
        <source>Qmmp Track Change Plugin</source>
        <translation>תוסף שינוי רצועה של Qmmp</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="52"/>
        <source>This plugin executes external command when current track is changed</source>
        <translation>תוסף זה מבצע פקודה חיצונית כאשר רצועה נוכחית משתנה</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
